@@ -36,8 +36,8 @@ def test_ordinal(test_input, expected):
         ([1000], "1,000"),
         ([10123], "10,123"),
         ([10311], "10,311"),
-        ([1000000], "1,000,000"),
-        ([1234567.25], "1,234,567.25"),
+        ([1_000_000], "1,000,000"),
+        ([1_234_567.25], "1,234,567.25"),
         (["100"], "100"),
         (["1000"], "1,000"),
         (["10123"], "10,123"),
@@ -123,6 +123,10 @@ def test_apnumber(test_input, expected):
         ("8.9", "8 9/10"),
         ("ten", "ten"),
         (None, None),
+        (1 / 3, "1/3"),
+        (1.5, "1 1/2"),
+        (0.3, "3/10"),
+        (0.333, "333/1000"),
     ],
 )
 def test_fractional(test_input, expected):
