@@ -24,6 +24,8 @@ ONE_YEAR = 365.25 * ONE_DAY
 
 with freeze_time("2020-02-02"):
     NOW = dt.datetime.now()
+    NOW_UTC = dt.datetime.now(tz=dt.timezone.utc)
+    NOW_UTC_PLUS_01_00 = dt.datetime.now(tz=dt.timezone(offset=dt.timedelta(hours=1)))
     TODAY = dt.date.today()
     TOMORROW = TODAY + ONE_DAY_DELTA
     YESTERDAY = TODAY - ONE_DAY_DELTA
@@ -331,6 +333,37 @@ def test_naturaldelta_minimum_unit_explicit(minimum_unit, seconds, expected):
     assert humanize.naturaldelta(delta, minimum_unit=minimum_unit) == expected
 
 
+@pytest.mark.parametrize(
+    "test_input, when, expected",
+    [
+        (NOW, NOW, "a moment"),
+        (NOW_UTC, NOW_UTC, "a moment"),
+    ],
+)
+def test_naturaldelta_when_explicit(test_input, when, expected):
+    # Act / Assert
+    assert humanize.naturaldelta(test_input, when=when) == expected
+
+
+@pytest.mark.parametrize(
+    "value, when",
+    [
+        (NOW_UTC, None),
+        (NOW_UTC, NOW),
+        (NOW_UTC_PLUS_01_00, None),
+        (NOW_UTC_PLUS_01_00, NOW),
+    ],
+)
+def test_naturaldelta_when_missing_tzinfo(value, when):
+    """Subtraction `when - value` is not defined by the `datetime` module when
+    either operand has not timezone-info (`tz=None`) and raises a TypeError.
+    """
+
+    # Act / Assert
+    with pytest.raises(TypeError):
+        humanize.naturaldelta(value, when=when)
+
+
 @pytest.mark.parametrize(
     "seconds, expected",
     [
@@ -463,6 +496,11 @@ def test_precisedelta_one_unit_enough(val, min_unit, expected):
             "microseconds",
             "1 year, 5 days and 2 seconds",
         ),
+        (
+            dt.timedelta(seconds=0.01),
+            "minutes",
+            "0 minutes",
+        ),
     ],
 )
 def test_precisedelta_multiple_units(val, min_unit, expected):
